@@ -933,7 +933,8 @@ def polar_processing(directory):
         out["hr"] = hr
     return out
 
-def gpslogger_processing(directory, file, interpolation=None, interval=(0,3)):
+
+def gpslogger_processing(directory, file, interpolation=None, interval=(list(range(0, 60, 1)), list(range(0, 60, 3)))):
     numeric = ["latitude", "longitude",
                "accuracy(m)", "altitude(m)", "geoid_height(m)", "speed(m/s)", "bearing(deg)", "sat_used", "sat_inview"]
     integer = ["sat_used","sat_inview"]
@@ -941,7 +942,7 @@ def gpslogger_processing(directory, file, interpolation=None, interval=(0,3)):
     df = pd.read_csv(directory+file,  index_col="date time")
     df.index = pd.to_datetime(df.index.map(
         lambda x: x.split(".")[0]), format=dtformat)
-    df.drop(labels=["name", "desc"], axis=1, inplace=True)
+    df.drop(labels=["type","name", "desc"], axis=1, inplace=True)
     if interpolation !=None:
         df = interpolate(df, 3, interpolation, pd.Timedelta(
             '00:0:10'), numeric_columns=numeric, integer_columns=integer,add_binary_counter=False)
